@@ -5,13 +5,16 @@
 //!
 //! These helpers includes enums to handle suites, codenames, and other fields found in Debian archive files.
 
-use std::fmt::{Display, Formatter};
-use std::str::FromStr;
+use std::{
+    fmt::{Display, Formatter},
+    hash::{Hash, Hasher},
+    str::FromStr,
+};
 
 use serde::{Deserialize, Serialize, Serializer};
 
-use crate::utils::TryFromStrVisitor;
 pub use crate::ParseError;
+use crate::utils::TryFromStrVisitor;
 
 /// "Extensions" to a codename or a suite
 ///
@@ -68,6 +71,19 @@ impl FromStr for Extension {
     }
 }
 
+/// Trait to add/remove archive extensions from `Suite` and `Codename`
+pub trait WithExtension {
+    /// Extend suite with an extension archive.
+    ///
+    /// An existing extension will overriden and the method has no effect for`unstable` and `experimental`.
+    fn with_extension(&self, extension: Extension) -> Self;
+
+    /// Remove an extension archive from the suite.
+    ///
+    /// The method has no effect for`unstable` and `experimental`.
+    fn without_extension(&self) -> Self;
+}
+
 /// Debian archive suites
 ///
 /// This enum describes the suite names found in the Debian archive.
@@ -85,11 +101,8 @@ pub enum Suite {
     Experimental,
 }
 
-impl Suite {
-    /// Extend suite with an extension archive.
-    ///
-    /// An existing extension will overriden and the method has no effect for`unstable` and `experimental`.
-    pub fn with_extension(&self, extension: Extension) -> Self {
+impl WithExtension for Suite {
+    fn with_extension(&self, extension: Extension) -> Self {
         match self {
             Self::Unstable | Self::Experimental => *self,
             Self::Testing(_) => Self::Testing(Some(extension)),
@@ -98,10 +111,7 @@ impl Suite {
         }
     }
 
-    /// Remove an extension archive from the suite.
-    ///
-    /// The method has no effect for`unstable` and `experimental`.
-    pub fn without_extension(&self) -> Self {
+    fn without_extension(&self) -> Self {
         match self {
             Self::Unstable | Self::Experimental => *self,
             Self::Testing(_) => Self::Testing(None),
@@ -174,7 +184,7 @@ impl<'de> Deserialize<'de> for Suite {
     where
         D: serde::Deserializer<'de>,
     {
-        deserializer.deserialize_str(TryFromStrVisitor::<Self>::new("a suite name"))
+        deserializer.deserialize_str(TryFromStrVisitor::new("a suite name"))
     }
 }
 
@@ -195,6 +205,26 @@ pub enum Codename {
     RCBuggy,
 }
 
+impl WithExtension for Codename {
+    fn with_extension(&self, extension: Extension) -> Self {
+        match self {
+            Self::Sid | Self::RCBuggy => *self,
+            Self::Trixie(_) => Self::Trixie(Some(extension)),
+            Self::Bookworm(_) => Self::Bookworm(Some(extension)),
+            Self::Bullseye(_) => Self::Bullseye(Some(extension)),
+        }
+    }
+
+    fn without_extension(&self) -> Self {
+        match self {
+            Self::Sid | Self::RCBuggy => *self,
+            Self::Trixie(_) => Self::Trixie(None),
+            Self::Bookworm(_) => Self::Bookworm(None),
+            Self::Bullseye(_) => Self::Bullseye(None),
+        }
+    }
+}
+
 impl Display for Codename {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::result::Result<(), std::fmt::Error> {
         match self {
@@ -280,14 +310,14 @@ impl<'de> Deserialize<'de> for Codename {
     where
         D: serde::Deserializer<'de>,
     {
-        deserializer.deserialize_str(TryFromStrVisitor::<Self>::new("a codename"))
+        deserializer.deserialize_str(TryFromStrVisitor::new("a codename"))
     }
 }
 
 /// Represents either a suite or codename
 ///
 /// This enum is useful whenever a suite name or codename works
-#[derive(Clone, Copy, Debug, PartialEq, Hash, Eq)]
+#[derive(Clone, Copy, Debug, Eq)]
 pub enum SuiteOrCodename {
     /// A suite
     Suite(Suite),
@@ -314,6 +344,45 @@ impl SuiteOrCodename {
     pub const STABLE_BACKPORTS: Self = Self::Suite(Suite::Stable(Some(Extension::Backports)));
 }
 
+impl PartialEq for SuiteOrCodename {
+    fn eq(&self, other: &Self) -> bool {
+        match (self, other) {
+            (Self::Suite(l0), Self::Suite(r0)) => l0 == r0,
+            (Self::Codename(l0), Self::Codename(r0)) => l0 == r0,
+            (Self::Suite(l0), Self::Codename(r0)) => Suite::from(*r0) == *l0,
+            (Self::Codename(l0), Self::Suite(r0)) => Suite::from(*l0) == *r0,
+        }
+    }
+}
+
+impl Hash for SuiteOrCodename {
+    fn hash<H>(&self, state: &mut H)
+    where
+        H: Hasher,
+    {
+        match self {
+            Self::Suite(suite) => suite.hash(state),
+            Self::Codename(codename) => Suite::from(*codename).hash(state),
+        }
+    }
+}
+
+impl WithExtension for SuiteOrCodename {
+    fn with_extension(&self, extension: Extension) -> Self {
+        match self {
+            Self::Suite(suite) => Self::Suite(suite.with_extension(extension)),
+            Self::Codename(suite) => Self::Codename(suite.with_extension(extension)),
+        }
+    }
+
+    fn without_extension(&self) -> Self {
+        match self {
+            Self::Suite(suite) => Self::Suite(suite.without_extension()),
+            Self::Codename(suite) => Self::Codename(suite.without_extension()),
+        }
+    }
+}
+
 impl From<Codename> for SuiteOrCodename {
     fn from(codename: Codename) -> Self {
         Self::Codename(codename)
@@ -389,7 +458,7 @@ impl<'de> Deserialize<'de> for SuiteOrCodename {
     where
         D: serde::Deserializer<'de>,
     {
-        deserializer.deserialize_str(TryFromStrVisitor::<Self>::new("a suite or a codename"))
+        deserializer.deserialize_str(TryFromStrVisitor::new("a suite or a codename"))
     }
 }
 
@@ -503,6 +572,8 @@ impl FromStr for Component {
 
 #[cfg(test)]
 mod test {
+    use std::hash::DefaultHasher;
+
     use super::*;
 
     #[test]
@@ -558,6 +629,28 @@ mod test {
         );
     }
 
+    #[test]
+    fn suite_or_codename_eq() {
+        assert_eq!(
+            SuiteOrCodename::UNSTABLE,
+            SuiteOrCodename::Codename(Codename::Sid)
+        );
+        assert_eq!(
+            SuiteOrCodename::STABLE_PU,
+            SuiteOrCodename::Codename(Codename::Bookworm(Some(Extension::ProposedUpdates)))
+        );
+    }
+
+    #[test]
+    fn suite_or_codename_hash() {
+        let mut hasher_1 = DefaultHasher::new();
+        let mut hasher_2 = DefaultHasher::new();
+
+        SuiteOrCodename::UNSTABLE.hash(&mut hasher_1);
+        SuiteOrCodename::Codename(Codename::Sid).hash(&mut hasher_2);
+        assert_eq!(hasher_1.finish(), hasher_2.finish());
+    }
+
     #[test]
     fn multi_arch_from_str() {
         assert_eq!(MultiArch::try_from("foreign").unwrap(), MultiArch::Foreign);
