@@ -31,8 +31,8 @@ use std::{
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
-use crate::utils::TryFromStrVisitor;
 pub use crate::ParseError;
+use crate::utils::TryFromStrVisitor;
 
 /// Compare non-digits part of a version
 ///
@@ -242,6 +242,22 @@ impl PartialEq for PackageVersion {
 
 impl Eq for PackageVersion {}
 
+impl PartialEq<&str> for PackageVersion {
+    fn eq(&self, other: &&str) -> bool {
+        self.partial_cmp(other) == Some(Ordering::Equal)
+    }
+}
+
+impl PartialOrd<&str> for PackageVersion {
+    fn partial_cmp(&self, other: &&str) -> Option<Ordering> {
+        let rhs = Self::try_from(*other);
+        match rhs {
+            Err(_) => None,
+            Ok(rhs) => self.partial_cmp(&rhs),
+        }
+    }
+}
+
 impl TryFrom<&str> for PackageVersion {
     type Error = ParseError;
 
@@ -296,7 +312,7 @@ impl<'de> Deserialize<'de> for PackageVersion {
     where
         D: serde::Deserializer<'de>,
     {
-        deserializer.deserialize_str(TryFromStrVisitor::<Self>::new("a package version"))
+        deserializer.deserialize_str(TryFromStrVisitor::new("a package version"))
     }
 }
 
